@@ -1,10 +1,9 @@
 from dez.http.client import HTTPClientRequest, HTTPClient
 import event
 
-def main(port):
-#    event.initialize(["poll"])
+def main(**kwargs):
     client = HTTPClient()
-    client.get_connection("www.google.com", 80, get_conn_cb, [])
+    client.get_connection(kwargs['domain'], kwargs['port'], get_conn_cb, [])
     event.dispatch()
     
 def get_conn_cb(conn):
